# Generated from aspida.g4 by ANTLR 4.8
from antlr4 import *
from egida.dsl.parser.aspida_parser import AspidaParser

# This class defines a complete listener for a parse tree produced by aspidaParser.
class AspidaListener(ParseTreeListener):

    # Enter a parse tree produced by aspidaParser#program.
    def enterProgram(self, ctx:AspidaParser.ProgramContext):
        pass

    # Exit a parse tree produced by aspidaParser#program.
    def exitProgram(self, ctx:AspidaParser.ProgramContext):
        pass


    # Enter a parse tree produced by aspidaParser#main.
    def enterMain(self, ctx:AspidaParser.MainContext):
        pass

    # Exit a parse tree produced by aspidaParser#main.
    def exitMain(self, ctx:AspidaParser.MainContext):
        pass


    # Enter a parse tree produced by aspidaParser#hosts.
    def enterHosts(self, ctx:AspidaParser.HostsContext):
        pass

    # Exit a parse tree produced by aspidaParser#hosts.
    def exitHosts(self, ctx:AspidaParser.HostsContext):
        pass


    # Enter a parse tree produced by aspidaParser#tasks.
    def enterTasks(self, ctx:AspidaParser.TasksContext):
        pass

    # Exit a parse tree produced by aspidaParser#tasks.
    def exitTasks(self, ctx:AspidaParser.TasksContext):
        pass


    # Enter a parse tree produced by aspidaParser#variables.
    def enterVariables(self, ctx:AspidaParser.VariablesContext):
        pass

    # Exit a parse tree produced by aspidaParser#variables.
    def exitVariables(self, ctx:AspidaParser.VariablesContext):
        pass


    # Enter a parse tree produced by aspidaParser#main_content.
    def enterMain_content(self, ctx:AspidaParser.Main_contentContext):
        pass

    # Exit a parse tree produced by aspidaParser#main_content.
    def exitMain_content(self, ctx:AspidaParser.Main_contentContext):
        pass


    # Enter a parse tree produced by aspidaParser#main_prop.
    def enterMain_prop(self, ctx:AspidaParser.Main_propContext):
        pass

    # Exit a parse tree produced by aspidaParser#main_prop.
    def exitMain_prop(self, ctx:AspidaParser.Main_propContext):
        pass


    # Enter a parse tree produced by aspidaParser#name.
    def enterName(self, ctx:AspidaParser.NameContext):
        pass

    # Exit a parse tree produced by aspidaParser#name.
    def exitName(self, ctx:AspidaParser.NameContext):
        pass


    # Enter a parse tree produced by aspidaParser#connection.
    def enterConnection(self, ctx:AspidaParser.ConnectionContext):
        pass

    # Exit a parse tree produced by aspidaParser#connection.
    def exitConnection(self, ctx:AspidaParser.ConnectionContext):
        pass


    # Enter a parse tree produced by aspidaParser#description.
    def enterDescription(self, ctx:AspidaParser.DescriptionContext):
        pass

    # Exit a parse tree produced by aspidaParser#description.
    def exitDescription(self, ctx:AspidaParser.DescriptionContext):
        pass


    # Enter a parse tree produced by aspidaParser#hosts_list.
    def enterHosts_list(self, ctx:AspidaParser.Hosts_listContext):
        pass

    # Exit a parse tree produced by aspidaParser#hosts_list.
    def exitHosts_list(self, ctx:AspidaParser.Hosts_listContext):
        pass


    # Enter a parse tree produced by aspidaParser#host.
    def enterHost(self, ctx:AspidaParser.HostContext):
        pass

    # Exit a parse tree produced by aspidaParser#host.
    def exitHost(self, ctx:AspidaParser.HostContext):
        pass


    # Enter a parse tree produced by aspidaParser#tasks_content.
    def enterTasks_content(self, ctx:AspidaParser.Tasks_contentContext):
        pass

    # Exit a parse tree produced by aspidaParser#tasks_content.
    def exitTasks_content(self, ctx:AspidaParser.Tasks_contentContext):
        pass


    # Enter a parse tree produced by aspidaParser#tasks_prop.
    def enterTasks_prop(self, ctx:AspidaParser.Tasks_propContext):
        pass

    # Exit a parse tree produced by aspidaParser#tasks_prop.
    def exitTasks_prop(self, ctx:AspidaParser.Tasks_propContext):
        pass


    # Enter a parse tree produced by aspidaParser#sections.
    def enterSections(self, ctx:AspidaParser.SectionsContext):
        pass

    # Exit a parse tree produced by aspidaParser#sections.
    def exitSections(self, ctx:AspidaParser.SectionsContext):
        pass


    # Enter a parse tree produced by aspidaParser#points.
    def enterPoints(self, ctx:AspidaParser.PointsContext):
        pass

    # Exit a parse tree produced by aspidaParser#points.
    def exitPoints(self, ctx:AspidaParser.PointsContext):
        pass


    # Enter a parse tree produced by aspidaParser#controls.
    def enterControls(self, ctx:AspidaParser.ControlsContext):
        pass

    # Exit a parse tree produced by aspidaParser#controls.
    def exitControls(self, ctx:AspidaParser.ControlsContext):
        pass


    # Enter a parse tree produced by aspidaParser#exclusions.
    def enterExclusions(self, ctx:AspidaParser.ExclusionsContext):
        pass

    # Exit a parse tree produced by aspidaParser#exclusions.
    def exitExclusions(self, ctx:AspidaParser.ExclusionsContext):
        pass


    # Enter a parse tree produced by aspidaParser#vars_content.
    def enterVars_content(self, ctx:AspidaParser.Vars_contentContext):
        pass

    # Exit a parse tree produced by aspidaParser#vars_content.
    def exitVars_content(self, ctx:AspidaParser.Vars_contentContext):
        pass


    # Enter a parse tree produced by aspidaParser#vars_prop.
    def enterVars_prop(self, ctx:AspidaParser.Vars_propContext):
        pass

    # Exit a parse tree produced by aspidaParser#vars_prop.
    def exitVars_prop(self, ctx:AspidaParser.Vars_propContext):
        pass


    # Enter a parse tree produced by aspidaParser#value.
    def enterValue(self, ctx:AspidaParser.ValueContext):
        pass

    # Exit a parse tree produced by aspidaParser#value.
    def exitValue(self, ctx:AspidaParser.ValueContext):
        pass


    # Enter a parse tree produced by aspidaParser#str_array.
    def enterStr_array(self, ctx:AspidaParser.Str_arrayContext):
        pass

    # Exit a parse tree produced by aspidaParser#str_array.
    def exitStr_array(self, ctx:AspidaParser.Str_arrayContext):
        pass


    # Enter a parse tree produced by aspidaParser#cadena.
    def enterCadena(self, ctx:AspidaParser.CadenaContext):
        pass

    # Exit a parse tree produced by aspidaParser#cadena.
    def exitCadena(self, ctx:AspidaParser.CadenaContext):
        pass


    # Enter a parse tree produced by aspidaParser#array.
    def enterArray(self, ctx:AspidaParser.ArrayContext):
        pass

    # Exit a parse tree produced by aspidaParser#array.
    def exitArray(self, ctx:AspidaParser.ArrayContext):
        pass


    # Enter a parse tree produced by aspidaParser#ip_v4.
    def enterIp_v4(self, ctx:AspidaParser.Ip_v4Context):
        pass

    # Exit a parse tree produced by aspidaParser#ip_v4.
    def exitIp_v4(self, ctx:AspidaParser.Ip_v4Context):
        pass


    # Enter a parse tree produced by aspidaParser#single_ip.
    def enterSingle_ip(self, ctx:AspidaParser.Single_ipContext):
        pass

    # Exit a parse tree produced by aspidaParser#single_ip.
    def exitSingle_ip(self, ctx:AspidaParser.Single_ipContext):
        pass


    # Enter a parse tree produced by aspidaParser#ip_range.
    def enterIp_range(self, ctx:AspidaParser.Ip_rangeContext):
        pass

    # Exit a parse tree produced by aspidaParser#ip_range.
    def exitIp_range(self, ctx:AspidaParser.Ip_rangeContext):
        pass


    # Enter a parse tree produced by aspidaParser#ip_v6.
    def enterIp_v6(self, ctx:AspidaParser.Ip_v6Context):
        pass

    # Exit a parse tree produced by aspidaParser#ip_v6.
    def exitIp_v6(self, ctx:AspidaParser.Ip_v6Context):
        pass


    # Enter a parse tree produced by aspidaParser#h16.
    def enterH16(self, ctx:AspidaParser.H16Context):
        pass

    # Exit a parse tree produced by aspidaParser#h16.
    def exitH16(self, ctx:AspidaParser.H16Context):
        pass


    # Enter a parse tree produced by aspidaParser#ls32.
    def enterLs32(self, ctx:AspidaParser.Ls32Context):
        pass

    # Exit a parse tree produced by aspidaParser#ls32.
    def exitLs32(self, ctx:AspidaParser.Ls32Context):
        pass


    # Enter a parse tree produced by aspidaParser#hexdigit.
    def enterHexdigit(self, ctx:AspidaParser.HexdigitContext):
        pass

    # Exit a parse tree produced by aspidaParser#hexdigit.
    def exitHexdigit(self, ctx:AspidaParser.HexdigitContext):
        pass



del AspidaParser